@@ -15,7 +15,10 @@ ALIAS_REGEX = re.compile(r"//(.+)\n")
 EXPRESSION_COLUMN_NAME_REGEX = re.compile(r"\"(.*?[^\\])\"")
 STRING_LITERAL_REGEX = re.compile(r"'(.*?[^\\])'")
 FUNCTION_LITERAL_REGEX = re.compile(
-    r"(bucket|match|fullmatch|search|indexof)\(.*?,\s*(intern\(\'(.+)\'\)).*\)"
+    r"(bucket|match|match_all|search|indexof)\(.*?,\s*(intern\(\'(.+)\'\)).*\)"
+)
+REPLACE_FN_REGEX = re.compile(
+    r"(replace_all|replace)\(.*?,\s*(intern\(\'(.*)\'\)),.*\)"
 )
 BOOLEAN_LITERAL_REGEX = re.compile(r"([a-zA-Z_]+[a-zA-Z0-9_]*)")
 
@@ -172,9 +175,6 @@ def _parse_expression_strings(expressions):
 
         if alias_match:
             alias = alias_match.group(1).strip()
-
-            # Remove the alias from the expression
-            parsed = re.sub(ALIAS_REGEX, "", expression, count=1)
         else:
             # Expression itself is the alias
             alias = expression
@@ -206,8 +206,10 @@ def _parse_expression_strings(expressions):
         )
 
         # remove the `intern()` in bucket and regex functions that take
-        # string literal parameters.
+        # string literal parameters. TODO this logic should be centralized
+        # in C++ instead of being duplicated.
         parsed = re.sub(FUNCTION_LITERAL_REGEX, _replace_interned_param, parsed)
+        parsed = re.sub(REPLACE_FN_REGEX, _replace_interned_param, parsed)
 
         validated = [alias, expression, parsed, column_id_map]
 
